@@ -119,8 +119,8 @@ static void usage (int status) {
 "and above only. Available log-levels are 'mute', 'critical, 'error',\n"
 "'warning' and 'info'.\n"
 "\n"
-"The --features option allows to enable and disable http-handlers /seek and\n"
-"/index as well as tweak related behaviour. The 'flatindex' option concerns\n"
+"The --features option allows one to enable or disable /seek and /index\n"
+"http-handlers and change their respone: The 'flatindex' option concerns\n"
 "/index&flatindex=1 which recursively indexes all video file. It is disabled\n"
 "by defaults since a recursive search of the default docroot / can takes a\n"
 "very long time.\n"
